@@ -5,7 +5,6 @@ OC.L10N.register(
     "No file provided for import" : "Engin skrá valin til innflutnings",
     "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Bookmarks shared by %s" : "Bókamerki deilt af %s",
-    "Imported bookmarks" : "Innflutt bókamerki",
     "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
     "Select bookmark" : "Veldu bókamerki",
     "Details" : "Nánar",
@@ -97,12 +96,12 @@ OC.L10N.register(
     "Title" : "Titill",
     "Link" : "Tengill",
     "Enter bookmark URL" : "Settu inn slóð á bókamerki",
+    "Folder" : "Mappa",
     "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
     "Failed to create bookmark" : "Mistókst að búa til bókamerki",
     "Failed to save bookmark" : "Mistókst að vista bókamerki",
     "Failed to move bookmark" : "Mistókst að færa bókamerki",
     "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
-    "Import successful" : "Innflutningur tókst",
     "Failed to load tags" : "Mistókst að hlaða inn merkjum",
     "Failed to load folders" : "Mistókst að hlaða inn möppum",
     "Failed to delete folder" : "Mistókst að eyða möppu",
